<?php
/***************************************************************************\
*
*	Copyright (c) 2014 deltra Business Software GmbH & Co. KG
*	http://www.deltra.de
*	Zuletzt bearbeitet am: 2014-03-28
*
\***************************************************************************/

// Versionsnummer der Anbindung
$GLOBALS["VERSION"] = "4.0.00";

/**
 * VirtueMart 2.0 spezifisch
 * Holt das Tabellenpr�fix der Datenbanktabellen aus der Joomla! Konfigurationsdatei
 */
function db_prefix_aus_config_holen()
{
	$dir = dirname(__FILE__);
	if (!file_exists($dir.ORGAMAX_VIRTUEMART_CONFIG))
	{
		die(DeltraResources::getText(SHOPSYSTEM_CONFIG_NOT_FOUND));
	}
	
	require_once($dir.ORGAMAX_VIRTUEMART_CONFIG);
	//Config Objekt erzeugen. Dort werden von joomla alle Daten gespeichert
	$cfg = new JConfig();
	return $cfg->dbprefix;
}

/**
 * Erzeugt aus der Artkelbezeichnung den Artikelalias
 */
function create_slug($artikel_bezeichnung)
{
	$pattern = utf8_encode("/[^A-Za-z0-9\-]/");
	$pattern_sonderzeichen = "#[\ \!&,\.\?\%]#";
	
	$slug = "";
	$slug = mb_strtolower(str_replace(" ", "-", $artikel_bezeichnung));
	$slug = preg_replace($pattern, "", $slug);
	$slug = preg_replace($pattern_sonderzeichen, "", $slug);
	return $slug;
}

/**
 * lädt den übersetzten Laendernamen
 * @param $countrycode
 * @return string
 * @throws InvalidArgumentException
 */
function getTranslatedCountrynameForCountrycode($countrycode, $languageCode = "de-DE")
{
    // Check input parameters
    if( strlen($countrycode) != 3)
    {
        throw new InvalidArgumentException("Country Code must be in ISO 3166 ALPHA-3 format.");
    }

    // Check virtuemart language files
    $dir = dirname(__FILE__);
    $vmLanguageDir = $dir."/../../../administrator/language/".$languageCode."/";
    $vmLanguageFile = $vmLanguageDir.$languageCode.".com_virtuemart_countries.ini";
    if( !file_exists($vmLanguageFile) )
    {
        throw new Exception("File not found: ".$vmLanguageFile);
    }

    // Read translation out of file
    $countryname = "";
    try
    {
        $file = @fopen($vmLanguageFile, 'r');
        $prefix="COM_VIRTUEMART_COUNTRY_";
        $vmLanguageKey = $prefix.$countrycode;
        while( $row = fscanf($file, "%s") )
        {
            list($countryInfo) = $row;
            $keyPos = strpos($countryInfo, "=");
            $key = mb_substr($countryInfo, 0, $keyPos);

            if($key == $vmLanguageKey)
            {
                $keyPos += 2; // strip =" at the beginning
                $endPos = strlen($countryInfo) -1; // strip " at the end;
                $length = $endPos - $keyPos;
                $value = mb_substr($countryInfo, $keyPos, $length);
                $countryname = $value;
                break;
            }
        }
    }
    catch( Exception $e )
    {
        throw $e;
    }

    // Close file and dealloc memory
    fclose( $file );
    $file = null;
    unset($file);

    return $countryname;
}

/**
 * 	Bestellungen abholen
 */
function daten_holen()
{	
	$GLOBALS['datakind'] = 1; // Art der Verarbeitung, 1=query, 2=array, 3=xml
	
	// Ben�tigte Stati
	$order_status = "";
	
	// Bestellstatus aus Webshop Konfiguration ermitteln
	switch($GLOBALS['DEFAULT_ORDERS_STATUS'])
	{
		case 1:
			$order_status = 'P'; // Pending
			break;
		case 2:
			$order_status = 'C'; // Confirmed
			break;
		case 3:
			$order_status = 'X'; // Cancelled
			break;
		case 4:
			$order_status = 'R'; // Refunded
			break;
		case 5:
			$order_status = 'S'; // Shipped
			break;			
	}
	
	// Datenbank Tabellen-Prefix aus der Joomla! Konfiguration
	$db_tableprefix = db_prefix_aus_config_holen();
	
	// MySQL-Query vorbereiten
	$GLOBALS['query'] = '
		SELECT '
			.$db_tableprefix.'virtuemart_orders.virtuemart_order_id as orderID, '
			.$db_tableprefix.'virtuemart_order_items.virtuemart_order_item_id as Positionsnummer, '
			.$db_tableprefix.'virtuemart_orders.virtuemart_user_id as KundennummerWebshop, '
			.$db_tableprefix.'virtuemart_orders.order_number as BestellnummerShop, '
			.$db_tableprefix.'virtuemart_orders.created_on as Bestelldatum, '
			.$db_tableprefix.'virtuemart_orders.order_total as BestellwertBrutto, '
			.$db_tableprefix.'virtuemart_orders.order_shipment as FrachtkostenBrutto, '
			.$db_tableprefix.'virtuemart_orders.order_shipment_tax as FrachtkostenMwStProzent, '
			.$db_tableprefix.'virtuemart_orders.order_payment as ZuschlagkostenBrutto1, '
			.$db_tableprefix.'virtuemart_orders.order_payment_tax as ZuschlagkostenMwSt, '
			.$db_tableprefix.'virtuemart_orders.virtuemart_paymentmethod_id as Zahlungsart, '
			.$db_tableprefix.'virtuemart_orders.virtuemart_shipmentmethod_id as Lieferart, '
			.$db_tableprefix.'virtuemart_orders.customer_note as AnmerkungenBestellung, '
			.$db_tableprefix.'virtuemart_order_userinfos.company as Firmenname, '
			.$db_tableprefix.'virtuemart_order_userinfos.title as PersonAnrede, '
			.$db_tableprefix.'virtuemart_order_userinfos.last_name as PersonNachname, '
			.$db_tableprefix.'virtuemart_order_userinfos.first_name as PersonVorname, '
			.$db_tableprefix.'virtuemart_order_userinfos.address_1 as Strasse, '
			.$db_tableprefix.'virtuemart_order_userinfos.zip as Postleitzahl, '
			.$db_tableprefix.'virtuemart_order_userinfos.city as Ort, '
			.$db_tableprefix.'virtuemart_order_userinfos.virtuemart_country_id as Laendercode, '
			.$db_tableprefix.'virtuemart_order_userinfos.email as Email, '
			.$db_tableprefix.'virtuemart_order_userinfos.phone_1 as Telefon, '
			.$db_tableprefix.'virtuemart_order_userinfos.fax as Fax, '
			.$db_tableprefix.'virtuemart_order_userinfos.company as abweichendRechnungFirmenname, '
			.$db_tableprefix.'virtuemart_order_userinfos.title as abweichendRechnungPersAnrede, '
			.$db_tableprefix.'virtuemart_order_userinfos.last_name as abweichendRechnungPersNachname, '
			.$db_tableprefix.'virtuemart_order_userinfos.first_name as abweichendRechnungPersVorname, '
			.$db_tableprefix.'virtuemart_order_userinfos.address_1 as abweichendRechnungStrasse, '
			.$db_tableprefix.'virtuemart_order_userinfos.zip as abweichendRechnungPostleitzahl, '
			.$db_tableprefix.'virtuemart_order_userinfos.city as abweichendRechnungOrt, '
			.$db_tableprefix.'virtuemart_order_userinfos.virtuemart_country_id as abweichendRechnungLaendercode, '
			.$db_tableprefix.'virtuemart_order_userinfos.email as abweichendRechnungEmail, '
			.$db_tableprefix.'virtuemart_order_userinfos.phone_1 as abweichendRechnungTelefon, '
			.$db_tableprefix.'virtuemart_order_userinfos.fax as abweichendRechnungFax, '
			.$db_tableprefix.'virtuemart_order_userinfos.company as abweichendLieferungFirmenname, '
			.$db_tableprefix.'virtuemart_order_userinfos.title as abweichendLieferungPersAnrede, '
			.$db_tableprefix.'virtuemart_order_userinfos.last_name as abweichendLieferungPersNachname, '
			.$db_tableprefix.'virtuemart_order_userinfos.first_name as abweichendLieferungPersVorname, '
			.$db_tableprefix.'virtuemart_order_userinfos.address_1 as abweichendLieferungStrasse, '
			.$db_tableprefix.'virtuemart_order_userinfos.zip as abweichendLieferungPostleitzahl, '
			.$db_tableprefix.'virtuemart_order_userinfos.city as abweichendLieferungOrt, '
			.$db_tableprefix.'virtuemart_order_userinfos.virtuemart_country_id as abweichendLieferungLaendercode, '
			.$db_tableprefix.'virtuemart_order_userinfos.email as abweichendLieferungEmail, '
			.$db_tableprefix.'virtuemart_order_userinfos.phone_1 as abweichendLieferungTelefon, '
			.$db_tableprefix.'virtuemart_order_userinfos.fax as abweichendLieferungFax, '
			.$db_tableprefix.'virtuemart_order_items.virtuemart_product_id as produktID, '
			.$db_tableprefix.'virtuemart_order_items.order_item_sku as Artikelnummer, '
			.$db_tableprefix.'virtuemart_order_items.order_item_sku as ArtikelnummerShop, '
			.$db_tableprefix.'virtuemart_order_items.virtuemart_product_id as productID, '
			.$db_tableprefix.'virtuemart_order_items.order_item_name as abweichenderArtikeltext, '
			.$db_tableprefix.'virtuemart_order_items.product_quantity as Menge, '
			.$db_tableprefix.'virtuemart_order_items.product_item_price as abweichenderEinzelpreisNetto 
		FROM '
			.$db_tableprefix.'virtuemart_orders, '
			.$db_tableprefix.'virtuemart_order_userinfos, '
			.$db_tableprefix.'virtuemart_order_items 
		WHERE '
			.$db_tableprefix.'virtuemart_orders.virtuemart_order_id = '.$db_tableprefix.'virtuemart_order_userinfos.virtuemart_order_id
			AND address_type = "BT" 
			AND '.$db_tableprefix.'virtuemart_orders.virtuemart_order_id = '.$db_tableprefix.'virtuemart_order_items.virtuemart_order_id		
			AND '.$db_tableprefix.'virtuemart_orders.order_status = "'.$order_status.'"
	';
			
	return $GLOBALS['datakind'];
}

/**
 *	Bestelldaten �berpr�fen und �berarbeiten
 */
function row_ueberpruefen($row)
{
	// MR: 19.06.2013 - Sonderzeichen formatieren
	foreach($row as $key => $value)
	{
		$row[$key] =  html_entity_decode(htmlentities($row[$key], ENT_QUOTES, 'ISO-8859-1'),ENT_QUOTES, 'UTF-8');
	}
	
	// Datenbank Tabellen-Prefix aus der Joomla! Konfiguration
	$db_tableprefix = db_prefix_aus_config_holen();
	
	// abweichende Lieferadresse eintragen
	$query = '
		SELECT '
			.'company, title, last_name, first_name, address_1, zip, city, virtuemart_country_id, phone_1, fax, email 
		FROM '
			.$db_tableprefix.'virtuemart_order_userinfos
		WHERE '
			.'virtuemart_user_id = '.$row['KundennummerWebshop'].' 
			AND virtuemart_order_id = '.$row['orderID'].'
			AND address_type = "ST"';
	$result = mysql_query($query);
	
	if(mysql_num_rows($result) > 0)
	{
		while($data = mysql_fetch_assoc($result))
		{
			$row['abweichendLieferungFirmenname'] = $data['company'];
			$row['abweichendLieferungPersAnrede'] = $data['title'];
			$row['abweichendLieferungPersNachname'] = $data['last_name'];
			$row['abweichendLieferungPersVorname'] = $data['first_name'];
			$row['abweichendLieferungStrasse'] = $data['address_1'];
			$row['abweichendLieferungPostleitzahl'] = $data['zip'];
			$row['abweichendLieferungOrt'] = $data['city'];
			$row['abweichendLieferungLaendercode'] = $data['virtuemart_country_id'];
			$row['abweichendLieferungTelefon'] = $data['phone_1'];
			$row['abweichendLieferungFax'] = $data['fax'];
			$row['abweichendLieferungEmail'] = $data['email'];
		}
	}

	// abweichende Anrede eintragen
	$row['PersonAnrede'] = formatTitle($row['PersonAnrede']);
	
	// Anrede Rechnungsadresse
	$query = '
		SELECT title
		FROM '.$db_tableprefix.'virtuemart_order_userinfos 
		WHERE virtuemart_order_id = '.$row['orderID'].'
			AND address_type = "BT"';
	$result = mysql_query($query);
	while($data = mysql_fetch_assoc($result))
	{
		$row['abweichendRechnungPersAnrede'] = formatTitle($data['title']);
	}
	
	// Anrede Lieferadresse
	$query = '
		SELECT title
		FROM '.$db_tableprefix.'virtuemart_order_userinfos 
		WHERE virtuemart_order_id = '.$row['orderID'].'
			AND address_type = "ST"';
	$result = mysql_query($query);
	while($data = mysql_fetch_assoc($result))
	{
		$row['abweichendLieferungPersAnrede'] = formatTitle($data['title']);
	}
	
	// Land Standard
	$query = '
		SELECT country_2_code, country_3_code
		FROM '.$db_tableprefix.'virtuemart_countries 
		WHERE virtuemart_country_id = '.$row['Laendercode'];
	$result = mysql_query($query);
	while($data = mysql_fetch_assoc($result))
	{
        try
        {
            $row['Land'] = getTranslatedCountrynameForCountrycode($data['country_3_code']);
        }
        catch(Exception $e)
        {
            $row['Land'] = $data['country_3_code'];
        }
        $row['Laendercode'] = LaenderkuerzelISO2OMX($data['country_2_code']);

	}
	
	// Land Rechnungsadresse
	$query = '
		SELECT country_2_code, country_3_code
		FROM '.$db_tableprefix.'virtuemart_countries 
		WHERE virtuemart_country_id = '.$row['abweichendRechnungLaendercode'];
	$result = mysql_query($query);
	while($data = mysql_fetch_assoc($result))
	{
		$row['abweichendRechnungLaendercode'] = LaenderkuerzelISO2OMX($data['country_2_code']);
        $row['abweichendRechnungLand'] = getTranslatedCountrynameForCountrycode($data['country_3_code']);
	}

	// Land Lieferadresse
	$query = '
		SELECT country_2_code, country_3_code
		FROM '.$db_tableprefix.'virtuemart_countries 
		WHERE virtuemart_country_id = '.$row['abweichendLieferungLaendercode'];
	$result = mysql_query($query);
	while($data = mysql_fetch_assoc($result))
	{
		$row['abweichendLieferungLaendercode'] = LaenderkuerzelISO2OMX($data['country_2_code']);
        $row['abweichendLieferungLand'] = getTranslatedCountrynameForCountrycode($data['country_3_code']);
	}
	
	/*
	 * Kontodaten
	 * (so erstmal nicht in VM 2.0 integriert, vielleicht �ber Zusatzmodul)
	 */

	// Zahlungsart
	$query = '
		SELECT payment_name
		FROM '.$db_tableprefix.'virtuemart_paymentmethods_de_de 
		WHERE virtuemart_paymentmethod_id = '.$row['Zahlungsart'];
	$result = mysql_query($query);
	while($data = mysql_fetch_assoc($result))
	{
		$row['Zahlungsart'] = $data['payment_name'];
	}
	
	// Lieferart
	$query = '
		SELECT shipment_name
		FROM '.$db_tableprefix.'virtuemart_shipmentmethods_de_de 
		WHERE virtuemart_shipmentmethod_id = '.$row['Lieferart'];
	$result = mysql_query($query);
	while($data = mysql_fetch_assoc($result))
	{
		$row['Lieferart'] = $data['shipment_name'];
	}
	
	//Frachtkosten
	$shippingCost = (double)$row['FrachtkostenBrutto'] + (double)$row['FrachtkostenMwStProzent'];
	$row['FrachtkostenBrutto'] = number_format($shippingCost, 2);
	
	$query = '
		SELECT calc_value
		FROM '.$db_tableprefix.'virtuemart_calcs 
		WHERE virtuemart_calc_id = (
			SELECT tax_id 
			FROM '.$db_tableprefix.'virtuemart_shipment_plg_weight_countries
			WHERE virtuemart_order_id = '.$row['orderID'].')';
	$result = mysql_query($query);
	while($data = mysql_fetch_assoc($result))
	{
		$row['FrachtkostenMwStProzent'] = $data['calc_value'];
	}
	

	// Artikel Mehrwertsteuer eintragen
	$query = '
		SELECT calc_value
		FROM '.$db_tableprefix.'virtuemart_calcs
		WHERE virtuemart_calc_id = (
			SELECT product_tax_id
	  		FROM '.$db_tableprefix.'_virtuemart_product_prices
	  		WHERE virtuemart_product_id = (
	    		SELECT virtuemart_product_id
	    		FROM '.$db_tableprefix.'virtuemart_order_items
	    		WHERE virtuemart_order_id = '.$row['orderID'].'
	  		)
		)';
	$result = mysql_query($query);
	if($result != NULL && mysql_num_rows($result) > 0)
	{
		$row['abweichendeMwStProzent'] = mysql_result($result, 0);
	}	
 
	// �berarbeiteten Datensatz wieder zur�ckgeben
	return $row;	
}


/**
 * Artikeldaten vom ERP zum Webshop �bertragen
 */
function artikeldaten_orgamax_zu_shop()
{
	// Datenbank Tabellen-Prefix aus der Joomla! Konfiguration
	$db_tableprefix = db_prefix_aus_config_holen();
	
	// Artikeldaten vom ERP
	$articleFile = file_get_contents('php://input');
	
	// Verarbeitung der �bertragenen Artikeldaten
	if(!is_null($articleFile) && strlen($articleFile) > 0)
	{
		$articles = simplexml_load_string($articleFile);
		
		$amount_successfully_created = 0;
		$amount_articles = count($articles);
		
		// Mehrwertsteuers�tze aus Webshop verf�gbar machen
		$tax_array = array();
		$query	=  "SELECT
						virtuemart_calc_id,
						calc_kind,
						calc_value_mathop,
						calc_value,
						calc_currency
					FROM
						".$db_tableprefix."virtuemart_calcs
					WHERE
						(calc_value_mathop = '+%')
					AND (calc_kind = 'Tax')
					";
		$result = mysql_query($query) or die(xml_error_ausgeben(mysql_error(), __FILE__, __FUNCTION__, __LINE__));
		
		if(mysql_num_rows($result) > 0)
		{
			while($row = mysql_fetch_object($result))
			{
				$tax_array[] = $row;
			}
		}
	
		foreach($articles as $article)
		{
			// Formatieren von Artikelinformationen
			$ArtikelnummerWebshop =  html_entity_decode(htmlentities($article->ArtikelnummerWebshop, ENT_QUOTES, 'UTF-8'),ENT_QUOTES, 'ISO-8859-1');
			$Artikelbeschreibung = html_entity_decode(strip_tags(htmlentities($article->Artikelbeschreibung, ENT_QUOTES, 'UTF-8')),ENT_QUOTES, 'ISO-8859-1');
			$Artikelalias = create_slug($Artikelbeschreibung);
			$Anmerkungen = html_entity_decode(htmlentities($article->Anmerkungen, ENT_QUOTES, 'UTF-8'),ENT_QUOTES, 'ISO-8859-1');
			$Anmerkungen_kurz = substr($Anmerkungen,0,254);
			$Einheit = html_entity_decode(htmlentities($article->Einheit, ENT_QUOTES, 'UTF-8'),ENT_QUOTES, 'ISO-8859-1');
			$articleCurrency = "47";
			
			// W�hrung des Artikels der W�hrungs-ID in Virtuemart zuordnen (Standard aus Virtuemart)
			// Tabelle: virtuemart_currencies
			if($article->ArtikelpreisWaehrung == "\$")
			{
				$articleCurrency = "144";
			}
			else if($article->ArtikelpreisWaehrung == "CH")
			{
				$articleCurrency = "27";
			}
			else if($article->ArtikelpreisWaehrung == "GBP")
			{
				$articleCurrency = "52";	
			}
			else
			{
				$articleCurrency = "47";	
			}
			
			// Artikelpreis
			$price = 0.0;
			
			if($article->ArtikelpreisNetto != 'DSC_IGNORE')
			{
				$price = str_replace(",",".", $article->ArtikelpreisNetto);
			}
			else
			{
				$tempValue = $article->ArtikelpreisBrutto;
				$price = str_replace(",",".", $tempValue);
			}
			
			// Artikelgewicht
			$weight = 0.0;
			$weight = str_replace(",",".", $article->Gewicht);
			
			// Artikel neu anlegen
			//Shopper Group ID anpassen, wenn der Artikel in einer anderen Gruppe landen soll
			
			// Stammdaten
			$query  =  "INSERT INTO ".$db_tableprefix."virtuemart_products
							(
								virtuemart_vendor_id,
								product_parent_id,
								product_sku,
								product_weight,
								product_length,
								product_width,
								product_height,
								product_url,
								product_in_stock,
								product_ordered,
								product_special,
								product_sales,
								product_unit,
								published,
								created_on,
								created_by,
								modified_on
							)
							VALUES
							(
								1,
								0,
								'$ArtikelnummerWebshop',
								'$weight',
								0,
								0,
								0,
								'',
								0,
								0,
								0,
								0,
								'$Einheit',
								0,
								NOW(),
								0,
								NOW()
							)";
			$result = mysql_query($query) or die(xml_error_ausgeben(mysql_error(), __FILE__, __FUNCTION__, __LINE__));	
			
			// Zusatzinformationen (Preis, Steuersatz, etc.)
			if(mysql_affected_rows() > 0)
			{
				$product_id = mysql_insert_id();
				
				// MwSt ID aus Webshop dem Artikel zuordnen
				$product_tax_id = -1;
				foreach($tax_array as $value)
				{
					$calc_value = (int)$value->calc_value;
					if($calc_value == (int)$article->MwStValue)
					{
						$product_tax_id = $value->virtuemart_calc_id;
						break;
					}
				}
				
				// Preisinformationen zu angelegtem Produkt hinterlegen
				$query  =  "INSERT INTO ".$db_tableprefix."virtuemart_product_prices
							(
								virtuemart_product_id,
								product_price,
								product_currency,
								product_tax_id
							)
							VALUES
							(
								".mysql_real_escape_string($product_id).",
								".mysql_real_escape_string($price).",
								".mysql_real_escape_string($articleCurrency).",
								".mysql_real_escape_string($product_tax_id)."
							)";
				$result = mysql_query($query) or die(xml_error_ausgeben(mysql_error(), __FILE__, __FUNCTION__, __LINE__));
				
				// Pr�fen, ob Artikelalias schon existiert
				$query  =  "SELECT *
							FROM
								".$db_tableprefix."virtuemart_products_de_de
							WHERE
								slug = '".mysql_real_escape_string($Artikelalias)."'
							";
				$result = mysql_query($query) or die(xml_error_ausgeben(mysql_error(), __FILE__, __FUNCTION__, __LINE__));
				
				$slugCount = mysql_num_rows($result);
				if ($slugCount >= 1)
				{
					$Artikelalias .= $slugCount;
				}
				
				// Artikelbeschreibung hinterlegen
				$query  =  "INSERT INTO ".$db_tableprefix."virtuemart_products_de_de
							(
								virtuemart_product_id,
								product_name,
								product_s_desc,
								product_desc,
								slug
							)
							VALUES
							(
								'".mysql_real_escape_string($product_id)."',
								'".mysql_real_escape_string($Artikelbeschreibung)."',
								'".mysql_real_escape_string($Anmerkungen_kurz)."',
								'".mysql_real_escape_string($Anmerkungen)."',
								'".mysql_real_escape_string($Artikelalias)."'
							)";
				$result = mysql_query($query) or die(xml_error_ausgeben(mysql_error(), __FILE__, __FUNCTION__, __LINE__));
				
				// Artikelkategorie ggf. anlegen und zuweisen
				if(!empty($article->Artikelkategorie) AND ($article->Artikelkategorie != "DSC_IGNORE"))
				{
					$Artikelkategorie = mysql_real_escape_string($article->Artikelkategorie);
					$query  =  "SELECT
									virtuemart_category_id
								FROM
									".$db_tableprefix."virtuemart_categories_de_de
								WHERE
									(category_name = '".$Artikelkategorie."')
								OR  (category_description = '".$Artikelkategorie."')
								";
					$result = mysql_query($query) or die(xml_error_ausgeben(mysql_error(), __FILE__, __FUNCTION__, __LINE__));
					
					// Artikelkategorie anlegen
					$categoryId = 0;
					if(mysql_num_rows($result) <= 0)
					{
						$query  =  "INSERT INTO ".$db_tableprefix."virtuemart_categories
									(
										virtuemart_vendor_id,
										category_template,
										category_layout,
										category_product_layout,
										products_per_row,
										shared,
										published,
										created_on,
										modified_on
									)
									VALUES
									(
										1,
										0,
										'default',
										'default',
										3,
										0,
										1,
										NOW(),
										NOW()
									)
									";
						$result = mysql_query($query) or die(xml_error_ausgeben(mysql_error(), __FILE__, __FUNCTION__, __LINE__));
						$categoryId = mysql_insert_id();
						$categorySlug = create_slug($Artikelkategorie);
						
						$query  =  "INSERT INTO ".$db_tableprefix."virtuemart_categories_de_de
									(
										virtuemart_category_id,
										category_name,
										category_description,
										slug
									)
									VALUES
									(
										'$categoryId',
										'$Artikelkategorie',
										'$Artikelkategorie',
										'$categorySlug'
									)
									";
						$result = mysql_query($query) or die(xml_error_ausgeben(mysql_error(), __FILE__, __FUNCTION__, __LINE__));
					}
					else
					{
						$fetchResult = mysql_fetch_assoc($result);
						$categoryId = $fetchResult["virtuemart_category_id"];
					}
					
					// Artikelkategorie zuweisen
					if($categoryId != 0)
					{
						$query  =  "INSERT INTO ".$db_tableprefix."virtuemart_product_categories
									(
										virtuemart_product_id,
										virtuemart_category_id,
										ordering
									)
									VALUES
									(
										'$product_id',
										'$categoryId',
										0
									)
									";
						$result = mysql_query($query) or die(xml_error_ausgeben(mysql_error(), __FILE__, __FUNCTION__, __LINE__));
					}
				}
				
				if(mysql_affected_rows() > 0){					
					$amount_successfully_created++;
				}
			}
		}
		WriteXMLResult(mysql_error(), $amount_successfully_created);
	}
	else
	{
		WriteXMLResult(0, 0);		
	}
}

function setze_lagerbestand_im_shop()
{
	// Datenbank Tabellen-Prefix aus der Joomla! Konfiguration
	$db_tableprefix = db_prefix_aus_config_holen();
	
	// Artikeldaten vom ERP
	$articleFile = file_get_contents('php://input');

	if($articleFile != null && strlen($articleFile) > 0) {
			
		$articles = simplexml_load_string(($articleFile));
		
		$amount_successfully_created = 0;
		$amount_articles = count($articles);
		
		foreach($articles as $article)
		{
			$articleNr =  html_entity_decode(htmlentities($article->ArtikelnummerWebshop, ENT_QUOTES, 'UTF-8'),ENT_QUOTES, 'ISO-8859-1');			
			
			// Lagerbestand zu Artikel hinterlegen
			$query  =  "UPDATE ".$db_tableprefix."virtuemart_products
						SET
							product_in_stock = $article->LagerBestandAktuell,
							low_stock_notification = $article->LagerMindestBestand
						WHERE
							product_sku = '$articleNr'
						";
			$result = mysql_query($query) or die(xml_error_ausgeben(mysql_error(), __FILE__, __FUNCTION__, __LINE__));
			
			if($result > 0)
			{
				$amount_successfully_created++;
			}
			
		}
		WriteXMLResult($amount_articles, $amount_successfully_created);
	}
	else {
		WriteXMLResult(0, 0);
	}
}

function pruefeOffeneBestellungenImShop()
{
	// Datenbank Tabellen-Prefix aus der Joomla! Konfiguration
	$db_tableprefix = db_prefix_aus_config_holen();
	$orderStatus = '';
	switch($GLOBALS["DEFAULT_ORDERS_STATUS"]){
		case 1:
			$orderStatus = 'P';
			break;
		case 2:
			$orderStatus = 'C';
			break;
		case 3:
			$orderStatus = 'X';
			break;
		case 4:
			$orderStatus = 'R';
			break;
		case 5:
			$orderStatus = 'S';
			break;
	}
	
	$query = "SELECT count(virtuemart_order_id) FROM ".$db_tableprefix."virtuemart_orders WHERE order_status = '".$orderStatus."'";
	
	$result = mysql_query(($query));
	
	if(mysql_num_rows($result) > 0)
	{
		$value = mysql_result($result, 0);
		
		if($value > 0)
		{
			echo 1;
		}
		else
		{
			echo 0;
		}
	}
	else
	{
		echo 0;		
	}
}

function hole_Artikelliste_fuer_export()
{
	// Datenbank Tabellen-Prefix aus der Joomla! Konfiguration
	$db_tableprefix = db_prefix_aus_config_holen();
	/** XML-Dokument erzeugen */
	$dom = new DomDocument('1.0');
	$dom->xmlStandalone = true;
	$dom->encoding="utf-8";
	$domProducts = $dom->appendChild($dom->createElement('ArtikelListeWebshop'));
	$query = '';
	
	
	if($GLOBALS['attributes_import'])
	{	// Artikel mit Attributen mit importieren
		$query = "	SELECT
						products.virtuemart_product_id,
						products.product_sku,
						products_de.product_name
					FROM
						".$db_tableprefix."virtuemart_products products,
						".$db_tableprefix."virtuemart_products_de_de products_de
					WHERE
						(products.virtuemart_product_id = products_de.virtuemart_product_id)";
	}
	else 
	{	// Artikel ohne Attribute importieren
		$query = "	SELECT
						products.virtuemart_product_id,
						products.product_sku,
						products_de.product_name
					FROM
						".$db_tableprefix."virtuemart_products products,
						".$db_tableprefix."virtuemart_products_de_de products_de
					WHERE
						(products.product_parent_id = 0)
					AND (products.virtuemart_product_id = products_de.virtuemart_product_id)";
	}
	$result = mysql_query($query) OR die(xml_error_ausgeben(mysql_error(), __FILE__, __FUNCTION__, __LINE__));
	
	if(mysql_num_rows($result) > 0)
	{
		while($articleRow = mysql_fetch_assoc($result))
		{
			$artikelRow = $domProducts->appendChild($dom->createElement('row'));
			Add_NewDocElement($dom, $artikelRow, 'ArtikelnummerWebshop', html_entity_decode(htmlentities($articleRow["product_sku"], ENT_QUOTES, 'ISO-8859-1'),ENT_QUOTES, 'UTF-8'));
			Add_NewDocElement($dom, $artikelRow, 'Artikelbeschreibung', html_entity_decode(htmlentities($articleRow["product_name"], ENT_QUOTES, 'ISO-8859-1'),ENT_QUOTES, 'UTF-8'));
			
		}
	}
	$dom->formatOutput = true;
	//zur�ck geben
	echo $dom->saveXML();
}

function setze_Artikelpreise_im_shop()
{
	// Datenbank Tabellen-Prefix aus der Joomla! Konfiguration
	$db_tableprefix = db_prefix_aus_config_holen();
	
	// Artikeldaten vom ERP
	$articleFile = file_get_contents('php://input');
	
	if($articleFile != null && strlen($articleFile) > 0)
	{
		$articles = simplexml_load_string(($articleFile));
		
		$amount_successfully_created = 0;
		$amount_articles = count($articles);
		
		foreach($articles as $article)
		{
			$article_sku =  html_entity_decode(htmlentities($article->ArtikelnummerWebshop, ENT_QUOTES, 'UTF-8'),ENT_QUOTES, 'ISO-8859-1');
			
			// Ist Artikel vorhanden?
			$query =   "SELECT
							virtuemart_product_id
						FROM
							".$db_tableprefix."virtuemart_products
						WHERE
							product_sku = '$article_sku'
					   ";
			$result = mysql_query($query) or die(xml_error_ausgeben(mysql_error(), __FILE__, __FUNCTION__, __LINE__));
			
			if(mysql_num_rows($result) > 0)
			{
				$product_id = mysql_result($result, 0);
				$price = 0.0;
				
				if($article->ArtikelpreisNetto != 'DSC_IGNORE')
				{
					$price = str_replace(',','.',$article->ArtikelpreisNetto);
				}
				else 
				{
					$price = str_replace(',','.',$article->ArtikelpreisBrutto);
				}
				
				$query =   "UPDATE 
								".$db_tableprefix."virtuemart_product_prices
							SET 
								product_price = '$price' 
							WHERE 
								virtuemart_product_id = $product_id
						   ";
				$result = mysql_query($query);
				
				if($result > 0)
				{
					$amount_successfully_created++;
				}
			}		  
		}
		
		WriteXMLResult($amount_articles,$amount_successfully_created);
	}
	else
	{
		WriteXMLResult(0,0);
	}
}

function artikeldaten_shop_zu_orgamax()
{
	$GLOBALS['datakind'] = 3; // Art der Verarbeitung, 1=query, 2=array, 3=xml
	
	// Datenbank Tabellen-Prefix aus der Joomla! Konfiguration
	$db_tableprefix = db_prefix_aus_config_holen();
	
	/** XML-Dokument erzeugen */
	$dom = new DomDocument('1.0');
	$dom->xmlStandalone = true;
	$dom->encoding="utf-8";
	 
	//Knoten f�r Artikelimport erzeugen
	$domProducts = $dom->appendChild($dom->createElement('Artikelimport'));
	
	// Artikelstammdaten aus Shop holen
	if($GLOBALS['attributes_import'])
	{
		$query =   "SELECT
						p.virtuemart_product_id as ArtikelID,
						p.product_sku as ArtikelnummerWebshop,
						p.product_weight as Gewicht,
						de.product_name as Artikelbeschreibung,
						de.product_desc as Anmerkung,
						pr.product_price as ArtikelpreisNetto,
						pr.product_tax_id as MwStID
					FROM
						".$db_tableprefix."virtuemart_products p
					LEFT JOIN
						".$db_tableprefix."virtuemart_products_de_de de ON (p.virtuemart_product_id = de.virtuemart_product_id)
					LEFT JOIN
						".$db_tableprefix."virtuemart_product_prices pr ON (p.virtuemart_product_id = pr.virtuemart_product_id)
					ORDER BY
						p.virtuemart_product_id
				   ";
	}
	else
	{
		$query =   "SELECT
						p.virtuemart_product_id as ArtikelID,
						p.product_sku as ArtikelnummerWebshop,
						p.product_weight as Gewicht,
						de.product_name as Artikelbeschreibung,
						de.product_desc as Anmerkung,
						pr.product_price as ArtikelpreisNetto,
						pr.product_tax_id as MwStID
					FROM
						".$db_tableprefix."virtuemart_products p
					LEFT JOIN
						".$db_tableprefix."virtuemart_products_de_de de ON (p.virtuemart_product_id = de.virtuemart_product_id)
					LEFT JOIN
						".$db_tableprefix."virtuemart_product_prices pr ON (p.virtuemart_product_id = pr.virtuemart_product_id)
					WHERE
						p.product_parent_id = 0
					ORDER BY
						p.virtuemart_product_id
				   ";
	}
	$result = mysql_query($query) or die(xml_error_ausgeben(mysql_error(), __FILE__, __FUNCTION__, __LINE__));

	if($result != null && mysql_num_rows($result) > 0)
	{
		while($article = mysql_fetch_assoc($result))
		{
			$articleNr =  html_entity_decode(htmlentities($article['ArtikelnummerWebshop'], ENT_QUOTES, 'ISO-8859-1'),ENT_QUOTES, 'UTF-8');
			$articleBeschreibung =  html_entity_decode(htmlentities($article['Artikelbeschreibung'], ENT_QUOTES, 'ISO-8859-1'),ENT_QUOTES, 'UTF-8');
			
			//Steuern holen
			$mwstQuery =   "SELECT 
								calc_value 
							FROM 
								".$db_tableprefix."virtuemart_calcs 
							WHERE 
								virtuemart_calc_id = '".$article['MwStID']."'
						   ";
			
			$mwstResult =  mysql_query($mwstQuery);
			
			if($mwstResult != null && mysql_num_rows($mwstResult) > 0)
			{
				$article['MwStCode'] = mysql_result($mwstResult,0);
				$article['MwStCode'] = number_format($article['MwStCode'],0);
			}
			else
			{
				$article['MwStCode'] = 0;
			}
			
			//Artikel in XML �bertragen
			$artikelRow = $domProducts->appendChild($dom->createElement('row'));
			
			// Undefinierte Array Elemente setzen
			$article['Einheit'] = "";
			$article['Artikelkategorie'] = "";
			$article['Anmerkungen'] = "";
			Add_NewDocElement($dom, $artikelRow, 'Artikelnummer', '');
			Add_NewDocElement($dom, $artikelRow, 'ArtikelnummerWebshop', $articleNr);
			Add_NewDocElement($dom, $artikelRow, 'Artikelbeschreibung', $articleBeschreibung);
			Add_NewDocElement($dom, $artikelRow, 'MwStCode', ($article['MwStCode']));
			Add_NewDocElement($dom, $artikelRow, 'Einheit', html_entity_decode(htmlentities($article['Einheit'], ENT_QUOTES, 'ISO-8859-1'),ENT_QUOTES, 'UTF-8'));
			Add_NewDocElement($dom, $artikelRow, 'Artikelkategorie', $article['Artikelkategorie']);
			Add_NewDocElement($dom, $artikelRow, 'Gewicht', number_format($article['Gewicht'],4));
			Add_NewDocElement($dom, $artikelRow, 'Volumen', '');
			Add_NewDocElement($dom, $artikelRow, 'Anmerkungen',htmlspecialchars(strip_tags($article['Anmerkungen']),ENT_QUOTES, 'UTF-8'));
			Add_NewDocElement($dom, $artikelRow, 'ArtikelpreisNetto', number_format($article['ArtikelpreisNetto'],4));
			Add_NewDocElement($dom, $artikelRow, 'ArtikelpreisBrutto', '');
			Add_NewDocElement($dom, $artikelRow, 'Einkaufspreis', '');
			Add_NewDocElement($dom, $artikelRow, 'Artikelbild','');
			Add_NewDocElement($dom, $artikelRow, 'IndividuellesFeld1', '');
			Add_NewDocElement($dom, $artikelRow, 'IndividuellesFeld2','');
			Add_NewDocElement($dom, $artikelRow, 'IndividuellesFeld3', '');
			Add_NewDocElement($dom, $artikelRow, 'IndividuellesFeld4','');
			Add_NewDocElement($dom, $artikelRow, 'IndividuellesFeld5', '');
			
			if($GLOBALS['attributes_import'])
			{
				$attributesQuery = "SELECT ".
									 $db_tableprefix."virtuemart_products.product_sku as ArtikelnummerWebshop,".
									 $db_tableprefix."virtuemart_products.product_weight as Gewicht,".
									 $db_tableprefix."virtuemart_products.product_unit as Einheit,".
									 $db_tableprefix."virtuemart_products_de_de.product_name as Artikelbeschreibung,".
									 $db_tableprefix."virtuemart_products_de_de.product_desc as Anmerkungen,".
									 $db_tableprefix."virtuemart_product_prices.product_tax_id as MwStCode,".
									 $db_tableprefix."virtuemart_product_prices.product_price as ArtikelpreisNetto
									 FROM ".
									 $db_tableprefix."virtuemart_products,".$db_tableprefix."virtuemart_products_de_de,".$db_tableprefix."virtuemart_product_prices
									 WHERE ".$db_tableprefix."virtuemart_products.product_parent_id = ".$article['shopid']." AND  ".$db_tableprefix."virtuemart_products.virtuemart_product_id = ".$db_tableprefix."virtuemart_products_de_de.virtuemart_product_id
									 AND ".$db_tableprefix."virtuemart_products.virtuemart_product_id = ".$db_tableprefix."virtuemart_product_prices.virtuemart_product_id";
				
				$attributesResult = mysql_query($attributesQuery);
				if($attributesResult != null && mysql_num_rows($attributesResult) > 0)
				{
					while($articleAttribute = mysql_fetch_assoc($attributesResult))
					{
						$articleAttributeNr =  html_entity_decode(htmlentities($articleAttribute['ArtikelnummerWebshop'], ENT_QUOTES, 'ISO-8859-1'),ENT_QUOTES, 'UTF-8');
						$articleAttributeDesc =  html_entity_decode(htmlentities($articleAttribute['Artikelbeschreibung'], ENT_QUOTES, 'ISO-8859-1'),ENT_QUOTES, 'UTF-8');
						
						//Steuern f�r die Attribute holen
						$mwstQuery = "SELECT calc_value FROM ".$db_tableprefix."virtuemart_calcs WHERE virtuemart_calc_id = ".$articleAttribute['MwStCode'];
						
						$mwstResult =  mysql_query($mwstQuery);
						
						if($mwstResult != null && mysql_num_rows($mwstResult) > 0){
							$articleAttribute['MwStCode'] = mysql_result($mwstResult,0);
							$articleAttribute['MwStCode'] = number_format($articleAttribute['MwStCode'],4);
						}
						else {
							$articleAttribute['MwStCode'] = $article['MwStCode'];
						}
						
						//Artikel in XML �bertragen
						$artikelAttributeRow = $domProducts->appendChild($dom->createElement('row'));
						
						Add_NewDocElement($dom, $artikelAttributeRow, 'Artikelnummer', '');
						Add_NewDocElement($dom, $artikelAttributeRow, 'ArtikelnummerWebshop', $articleAttributeNr);
						Add_NewDocElement($dom, $artikelAttributeRow, 'Artikelbeschreibung', $articleAttributeDesc);
						Add_NewDocElement($dom, $artikelAttributeRow, 'MwStCode', ($articleAttribute['MwStCode']));
						Add_NewDocElement($dom, $artikelAttributeRow, 'Einheit', html_entity_decode(htmlentities($articleAttribute['Einheit'], ENT_QUOTES, 'ISO-8859-1'),ENT_QUOTES, 'UTF-8'));
						Add_NewDocElement($dom, $artikelAttributeRow, 'Artikelkategorie', $articleAttribute['Artikelkategorie']);
						Add_NewDocElement($dom, $artikelAttributeRow, 'Gewicht', number_format($articleAttribute['Gewicht'],4));
						Add_NewDocElement($dom, $artikelAttributeRow, 'Volumen', '');
						Add_NewDocElement($dom, $artikelAttributeRow, 'Anmerkungen',strip_tags($article['Anmerkungen']));
						Add_NewDocElement($dom, $artikelAttributeRow, 'ArtikelpreisNetto', number_format($articleAttribute['ArtikelpreisNetto'],4));
						Add_NewDocElement($dom, $artikelAttributeRow, 'ArtikelpreisBrutto', '');
						Add_NewDocElement($dom, $artikelAttributeRow, 'Einkaufspreis', '');
						Add_NewDocElement($dom, $artikelAttributeRow, 'Artikelbild','');
						Add_NewDocElement($dom, $artikelAttributeRow, 'IndividuellesFeld1', '');
						Add_NewDocElement($dom, $artikelAttributeRow, 'IndividuellesFeld2','');
						Add_NewDocElement($dom, $artikelAttributeRow, 'IndividuellesFeld3', '');
						Add_NewDocElement($dom, $artikelAttributeRow, 'IndividuellesFeld4','');
						Add_NewDocElement($dom, $artikelAttributeRow, 'IndividuellesFeld5', '');
					}
				}
			}
		}
	}
	$dom->formatOutput = true;
    $GLOBALS['XMLDoc'] = $dom->saveXML();
	return $GLOBALS['datakind'];
}

function artRow_ueberpruefen($artRow)
{
	//NOTHING TO DO!
}

function status_aendern($orderId)
{
	// Datenbank Tabellen-Prefix aus der Joomla! Konfiguration
	$db_tableprefix = db_prefix_aus_config_holen();
	
	$ShopStatus = $GLOBALS["aendern_zu"];
	
	switch($ShopStatus){
		case 1:
			$ShopStatus = 'P';
			break;
		case 2:
			$ShopStatus = 'C';
			break;
		case 3:
			$ShopStatus = 'X';
			break;
		case 4:
			$ShopStatus = 'R';
			break;
		case 5:
			$ShopStatus = 'S';
			break;
	}
	$query  = 'SELECT order_status';
	$query .= ' FROM '.$db_tableprefix.'virtuemart_orders';
	$query .= ' WHERE virtuemart_order_id = '.$orderId;
	
	$data = mysql_query($query);
	if($data) {
		$erg = mysql_fetch_assoc($data);
		
		// Order_status vergleichen
		if($erg['order_status'] !=  'S'){
			// Update Befehl vorbereiten
			$query = 'UPDATE '.$db_tableprefix.'virtuemart_orders SET order_status = \''.$ShopStatus.'\' WHERE virtuemart_order_id = '.$orderId;
			mysql_query($query);
				
			//Kontrolliert ob der Update Befehl geklappt hat
			$error = mysql_error();
				
			if($error == ''){
				$query = 'UPDATE '.$db_tableprefix.'virtuemart_order_items SET order_status = \''.$ShopStatus.'\' WHERE virtuemart_order_id = '.$orderId;
				
				mysql_query($query);
				
				$error = mysql_error();
				
				if($error == ''){
					$query  = 'INSERT INTO '.$db_tableprefix.'virtuemart_order_histories(virtuemart_order_id,order_status_code,created_on,customer_notified)';
					$query .= ' VALUES('.$orderId.',\''.$ShopStatus.'\',\''.date('Y-m-d H:i:s').'\',1)';
					
					mysql_query($query);
					$error = mysql_error();
					if($error == ''){
						die(xml_success_ausgeben("Der Status der Bestellung '" . $orderId . "' wurde auf '" . $ShopStatus . "' gesetzt."));
					}
					else{
						die(xml_error_ausgeben("Bei der Fortschreibung der Shop History f&uuml;r die order_id: '$orderId' auf den Wert '$ShopStatus' trat ein Fehler auf. Das Query meldete MySql '. $error .'", __FILE__, __FUNCTION__, __LINE__));
					}
				}
				else{
					die(xml_error_ausgeben("Bei der Status&auml;nderung der Bestellung '$orderId' auf den Wert '$ShopStatus' trat ein Fehler auf. Das Query meldete MySql '. $error .'", __FILE__, __FUNCTION__, __LINE__));
				}
			}
			else{
				die(xml_error_ausgeben("Bei der Status&auml;nderung der Bestellung '$orderId' auf den Wert '$ShopStatus' trat ein Fehler auf. Das Query meldete MySql '. $error .'", __FILE__, __FUNCTION__, __LINE__));
			}
		}
	}
}

function starten()
{
	$dir = dirname(__FILE__);
	$joomlaConfigFile = $dir . ORGAMAX_VIRTUEMART_CONFIG;
	
	if (file_exists($joomlaConfigFile))
	{
		require_once($joomlaConfigFile);
		
		
		// Datenbankinformationen aus Joomla! Konfiguration holen
		// und in GLOBALS verf�gbar machen
		$cfg = new JConfig();
		try
		{
			$GLOBALS['sql_con'] = mysql_connect($cfg->host, $cfg->user, $cfg->password);
			
			// Verbindung zur Joomla!-Datenbank herstellen
			$db = mysql_select_db($cfg->db, $GLOBALS['sql_con']);
			
			// Falls keine Datenbank selektiert werden konnte
			if(!$db)
			{
				die(xml_error_ausgeben('Es wurde keine entsprechende Datenbank auf dem Server gefunden ',__FILE__, __FUNCTION__, __LINE__));
			}
		}
		catch(exception $e)
		{
			die(xml_error_ausgeben(' ',__FILE__, __FUNCTION__, __LINE__));
		}
	}
	else
	{
		die(xml_error_ausgeben($GLOBALS['err_msg']['shop_cfg'],__FILE__, __FUNCTION__, __LINE__));
	}
	
}

function ende()
{
	mysql_close($GLOBALS['sql_con']);
}

/**
 *	formatiert die Anrede
 */
function formatTitle($title)
{
	if(empty($title))
	{
		return "";
	}
	
	switch($title)
	{
		case "Mr":
			return "Herr";
		case "Mrs":
			return "Frau";
		case "Ms":
			return "Frau";
		default:
			return $title;
	}
}

?>
